@@ -13,7 +13,7 @@ from htmlgenerator import Lazy
 
 R = layout.grid.Row
 C = layout.grid.Col
-F = layout.form.FormField
+F = layout.forms.FormField
 
 
 def person_metadata():
