@@ -58,13 +58,8 @@ def export(request, queryset):
         return hg.F(lambda c: getattr(get_concrete_instance(c["row"]), field, ""))
 
     # insert last_name and first_name
-    name_field = [getattr(i, "sortingname", i) for i in columns].index("name")
-    columns.insert(
-        name_field + 1,
-        DataTableColumn(
-            layout.ObjectFieldLabel("last_name", models.NaturalPerson),
-            get_from_concret_object("last_name"),
-        ),
+    name_field = [getattr(i, "sortingname", i) for i in columns].index(
+        "default_sorting_name"
     )
     columns.insert(
         name_field + 1,
@@ -170,16 +165,19 @@ class PersonBrowseView(BrowseView):
             queryset=models.Term.objects.filter(vocabulary__slug="naturaltype"),
             widget=forms.CheckboxSelectMultiple,
             required=False,
+            label="",
         )
         legalperson_subtypes = forms.ModelMultipleChoiceField(
             queryset=models.Term.objects.filter(vocabulary__slug="legaltype"),
             widget=forms.CheckboxSelectMultiple,
             required=False,
+            label="",
         )
         personassociation_subtypes = forms.ModelMultipleChoiceField(
             queryset=models.Term.objects.filter(vocabulary__slug="associationtype"),
             widget=forms.CheckboxSelectMultiple,
             required=False,
+            label="",
         )
         tags = forms.ModelMultipleChoiceField(
             queryset=models.Term.objects.filter(vocabulary__slug="tag"),
@@ -315,7 +313,7 @@ class PersonBrowseView(BrowseView):
 
     def get_settingspanel(self):
         return hg.DIV(
-            layout.form.Form(
+            layout.forms.Form(
                 self._filterform(),
                 hg.DIV(
                     hg.DIV(
@@ -323,54 +321,40 @@ class PersonBrowseView(BrowseView):
                         hg.DIV(
                             hg.DIV(
                                 hg.DIV(
-                                    layout.form.FormField(
+                                    layout.forms.FormField(
                                         "naturalperson",
-                                        elementattributes={
-                                            "onclick": "updateCheckboxGroupItems(this.parentElement.parentElement)"
-                                        },
+                                        onclick="updateCheckboxGroupItems(this.parentElement.parentElement)",
                                     ),
                                     hg.DIV(
-                                        layout.form.FormField(
+                                        layout.forms.FormField(
                                             "naturalperson_subtypes",
-                                            elementattributes={
-                                                "style": "padding-left: 1rem",
-                                            },
+                                            style="padding-left: 1rem",
                                         ),
                                         style="margin-top: -2rem",
                                     ),
                                 ),
+                                layout.forms.FormField(
+                                    "personassociation",
+                                    onclick="updateCheckboxGroupItems(this.parentElement.parentElement)",
+                                ),
                                 hg.DIV(
-                                    layout.form.FormField(
-                                        "personassociation",
-                                        elementattributes={
-                                            "onclick": "updateCheckboxGroupItems(this.parentElement.parentElement)"
-                                        },
+                                    layout.forms.FormField(
+                                        "personassociation_subtypes",
+                                        style="padding-left: 1rem",
                                     ),
-                                    hg.DIV(
-                                        layout.form.FormField(
-                                            "personassociation_subtypes",
-                                            elementattributes={
-                                                "style": "padding-left: 1rem"
-                                            },
-                                        ),
-                                        style="margin-top: -2rem",
-                                    ),
-                                    style="margin-right: 16px",
+                                    style="margin-top: -2rem",
                                 ),
+                                style="margin-right: 16px",
                             ),
                             hg.DIV(
-                                layout.form.FormField(
+                                layout.forms.FormField(
                                     "legalperson",
-                                    elementattributes={
-                                        "onclick": "updateCheckboxGroupItems(this.parentElement.parentElement)"
-                                    },
+                                    onclick="updateCheckboxGroupItems(this.parentElement.parentElement)",
                                 ),
                                 hg.DIV(
-                                    layout.form.FormField(
+                                    layout.forms.FormField(
                                         "legalperson_subtypes",
-                                        elementattributes={
-                                            "style": "padding-left: 1rem"
-                                        },
+                                        style="padding-left: 1rem",
                                     ),
                                     style="margin-top: -2rem",
                                 ),
@@ -381,27 +365,24 @@ class PersonBrowseView(BrowseView):
                         style="border-right: #ccc solid 1px; margin: 0 16px 0 0",
                     ),
                     hg.DIV(
-                        hg.DIV(layout.helpers.Label(_("Tags"))),
                         hg.DIV(
-                            layout.form.FormField("tags"),
+                            layout.forms.FormField("tags"),
                             style="margin-right: 16px",
                         ),
                         style="border-right: #ccc solid 1px; margin: 0 16px 0 0; overflow-y: scroll",
                     ),
                     hg.DIV(
-                        hg.DIV(layout.helpers.Label(_("Languages"))),
                         hg.DIV(
-                            layout.form.FormField("preferred_language"),
+                            layout.forms.FormField("preferred_language"),
                             style="margin-right: 16px",
                         ),
                         style="border-right: #ccc solid 1px; margin: 0 16px 0 0",
                     ),
                     hg.DIV(
-                        hg.DIV(layout.helpers.Label(_("Status"))),
-                        hg.DIV(layout.form.FormField("status"), style="flex-grow: 0"),
+                        hg.DIV(layout.forms.FormField("status"), style="flex-grow: 0"),
                         hg.DIV(style="flex-grow: 1"),
                         hg.DIV(
-                            layout.form.FormField("trash"),
+                            layout.forms.FormField("trash"),
                             style="max-height: 2rem",
                         ),
                         style="display: flex; flex-direction: column",
