@@ -210,7 +210,7 @@ def confirm_delete_email(request, pk: int):
                         hg.H3(_("Delete email %s") % email.email),
                         hg.If(
                             enable_delete_mailer_contact_checkbox,
-                            bread.layout.form.FormField("delete_mailer_contact"),
+                            bread.layout.forms.FormField("delete_mailer_contact"),
                             hg.BaseElement(),
                         ),
                     ),
@@ -235,6 +235,7 @@ def confirm_delete_email(request, pk: int):
                     _class="bx--form-item",
                     style="margin-top: 2rem; display: inline-block; margin-left: 1rem;",
                 ),
+                layout.forms.helpers.Submit(_("Confirm")),
             ),
         ),
     )
